==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/history/translations/history_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Conversation</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historique</translation>
    </message>
    <message>
        <source>Chats History</source>
        <translation>Historique des conversation</translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation>Enregistrer le message dans l&apos;historique</translation>
    </message>
    <message>
        <source>Save chats with anonymous users</source>
        <translation>Enregistrer les conversations avec les utilisateurs anonymes</translation>
    </message>
    <message>
        <source>Status Changes</source>
        <translation>Modification d&apos;état</translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation>Enregistrer les modifications d&apos;état</translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation>Enregistrer les modifications d&apos;état dans l&apos;historique</translation>
    </message>
    <message>
        <source>Save status only with description</source>
        <translation>Enregistrer l&apos;état uniquement avec la description</translation>
    </message>
    <message>
        <source>Quotation</source>
        <translation>Citation</translation>
    </message>
    <message>
        <source>Quote message in chat window</source>
        <translation>Citer le message dans la fenêtre de conversation</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Raccourcis</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>View history</source>
        <translation>Voir l&apos;historique</translation>
    </message>
    <message>
        <source>Do not quote messages older than</source>
        <translation>Ne pas citer les message âgés de plus de </translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
</context>
<context>
    <name>ChatHistoryTab</name>
    <message>
        <source>&amp;Clear Chat History</source>
        <translation>&amp;Effacer l&apos;historique des conversations</translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <source>Clear History</source>
        <translation>Effacer l&apos;historique</translation>
    </message>
    <message>
        <source>%1 day(s) %2 hour(s)</source>
        <translation>%1 jour(s) %2 heure(s)</translation>
    </message>
</context>
<context>
    <name>HistoryBuddyDataWindowAddons</name>
    <message>
        <source>Store history</source>
        <translation>Historique de la boutique</translation>
    </message>
</context>
<context>
    <name>HistoryChatDataWindowAddons</name>
    <message>
        <source>Store history</source>
        <translation>Historique de la boutique</translation>
    </message>
</context>
<context>
    <name>HistoryMessagesTab</name>
    <message>
        <source>&amp;Remove entries</source>
        <translation>&amp;Supprimer les entrées</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtrer</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Do you really want to delete history?</source>
        <translation>Voulez-vous réellement supprimer l&apos;historique ?</translation>
    </message>
</context>
<context>
    <name>HistoryQueryResultsModel</name>
    <message>
        <source>Chat</source>
        <translation>Conversation</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Longueur</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Date</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <source>History</source>
        <translation>Historique</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <source>&amp;Clear Status History</source>
        <translation>&amp;Effacer l&apos;historique de l&apos;état</translation>
    </message>
    <message>
        <source>&amp;Clear SMS History</source>
        <translation>&amp;Effacer l&apos;historique des SMS</translation>
    </message>
    <message>
        <source>Chats</source>
        <translation>Conversations</translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation>États</translation>
    </message>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Chat history</source>
        <translation>Historique des conversations</translation>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search for:</source>
        <translation>Rechercher :</translation>
    </message>
    <message>
        <source>Chats</source>
        <translation>Conversations</translation>
    </message>
    <message>
        <source> - All chats - </source>
        <translation> - Toutes les conversations - </translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation>États</translation>
    </message>
    <message>
        <source> - All buddies - </source>
        <translation> - Tous les amis - </translation>
    </message>
    <message>
        <source>Smses</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source> - All recipients - </source>
        <translation> - Tous les destinataires - </translation>
    </message>
    <message>
        <source>By date</source>
        <translation>Par date</translation>
    </message>
    <message>
        <source>to</source>
        <translation>à</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Trouver</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Conversation</translation>
    </message>
    <message>
        <source>Buddy</source>
        <translation>Ami</translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation>Destinataire</translation>
    </message>
</context>
<context>
    <name>ShowHistoryActionDescription</name>
    <message>
        <source>View Chat History</source>
        <translation>Voir l&apos;historique des conversations</translation>
    </message>
    <message>
        <source>Show last %1 messages</source>
        <translation>Afficher les derniers %1 messages</translation>
    </message>
    <message>
        <source>Show messages since yesterday</source>
        <translation>Afficher les messages reçus depuis hier</translation>
    </message>
    <message>
        <source>Show messages from last 7 days</source>
        <translation>Afficher les messages des 7 derniers jours</translation>
    </message>
    <message>
        <source>Show messages from last 30 days</source>
        <translation>Afficher les messages des 30 derniers jours</translation>
    </message>
    <message>
        <source>Show whole history</source>
        <translation>Afficher tout l&apos;historique</translation>
    </message>
</context>
</TS>

==> kadu_1.2.orig.tar.bz2: kadu-1.2/plugins/history/translations/history_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Conversation</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historique</translation>
    </message>
    <message>
        <source>Chats History</source>
        <translation>Historique des conversation</translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation>Enregistrer le message dans l&apos;historique</translation>
    </message>
    <message>
        <source>Save chats with anonymous users</source>
        <translation>Enregistrer les conversations avec les utilisateurs anonymes</translation>
    </message>
    <message>
        <source>Status Changes</source>
        <translation>Modification d&apos;état</translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation>Enregistrer les modifications d&apos;état</translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation>Enregistrer les modifications d&apos;état dans l&apos;historique</translation>
    </message>
    <message>
        <source>Save status only with description</source>
        <translation>Enregistrer l&apos;état uniquement avec la description</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Raccourcis</translation>
    </message>
    <message>
        <source>View history</source>
        <translation>Voir l&apos;historique</translation>
    </message>
    <message>
        <source>Save chats in history</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>History in chat window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show messages from history since</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Choose time period in which messages can be quoted in chat window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>yesterday</source>
        <translation>hier</translation>
    </message>
    <message>
        <source>last week</source>
        <translation>la semaine dernière</translation>
    </message>
    <message>
        <source>last month</source>
        <translation>mois dernier</translation>
    </message>
    <message>
        <source>Limit number of messages from history</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Comportement</translation>
    </message>
    <message>
        <source>Chat window</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BuddyHistoryDeleteHandler</name>
    <message>
        <source>Chat history</source>
        <translation>Historique des conversations</translation>
    </message>
</context>
<context>
    <name>ChatHistoryTab</name>
    <message>
        <source>&amp;Clear Chat History</source>
        <translation>&amp;Effacer l&apos;historique des conversations</translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <source>Clear History</source>
        <translation>Effacer l&apos;historique</translation>
    </message>
</context>
<context>
    <name>HistoryBuddyConfigurationWidget</name>
    <message>
        <source>History</source>
        <translation>Histoire</translation>
    </message>
    <message>
        <source>Store history</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>HistoryChatConfigurationWidget</name>
    <message>
        <source>History</source>
        <translation>Histoire</translation>
    </message>
    <message>
        <source>Store history</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>HistoryMessagesTab</name>
    <message>
        <source>&amp;Remove entries</source>
        <translation>&amp;Supprimer les entrées</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtrer</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Do you really want to delete history?</source>
        <translation>Voulez-vous réellement supprimer l&apos;historique ?</translation>
    </message>
    <message>
        <source>Delete history</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>HistoryQueryResultsModel</name>
    <message>
        <source>Chat</source>
        <translation>Conversation</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Longueur</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Date</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titre</translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <source>History</source>
        <translation>Historique</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <source>&amp;Clear Status History</source>
        <translation>&amp;Effacer l&apos;historique de l&apos;état</translation>
    </message>
    <message>
        <source>&amp;Clear SMS History</source>
        <translation>&amp;Effacer l&apos;historique des SMS</translation>
    </message>
    <message>
        <source>Chats</source>
        <translation>Conversations</translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation>États</translation>
    </message>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search for:</source>
        <translation>Rechercher :</translation>
    </message>
    <message>
        <source>Chats</source>
        <translation>Conversations</translation>
    </message>
    <message>
        <source> - All chats - </source>
        <translation> - Toutes les conversations - </translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation>États</translation>
    </message>
    <message>
        <source> - All buddies - </source>
        <translation> - Tous les amis - </translation>
    </message>
    <message>
        <source>Smses</source>
        <translation>SMS</translation>
    </message>
    <message>
        <source> - All recipients - </source>
        <translation> - Tous les destinataires - </translation>
    </message>
    <message>
        <source>By date</source>
        <translation>Par date</translation>
    </message>
    <message>
        <source>to</source>
        <translation>à</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Trouver</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Conversation</translation>
    </message>
    <message>
        <source>Buddy</source>
        <translation>Ami</translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation>Destinataire</translation>
    </message>
</context>
<context>
    <name>ShowHistoryActionDescription</name>
    <message>
        <source>View Chat History</source>
        <translation>Voir l&apos;historique des conversations</translation>
    </message>
    <message>
        <source>Show last %1 messages</source>
        <translation>Afficher les derniers %1 messages</translation>
    </message>
    <message>
        <source>Show messages since yesterday</source>
        <translation>Afficher les messages reçus depuis hier</translation>
    </message>
    <message>
        <source>Show messages from last 7 days</source>
        <translation>Afficher les messages des 7 derniers jours</translation>
    </message>
    <message>
        <source>Show messages from last 30 days</source>
        <translation>Afficher les messages des 30 derniers jours</translation>
    </message>
    <message>
        <source>Show whole history</source>
        <translation>Afficher tout l&apos;historique</translation>
    </message>
</context>
</TS>
